cemento.axioms package — CEMENTO 0.13.0 documentation

Skip to main content
`Ctrl`+`K`

# cemento.axioms package

## Subpackages

- cemento.axioms.modules package
  - Submodules
  - cemento.axioms.modules.ms module
    - `MS`
      - `MS.And`
      - `MS.Asymmetric`
      - `MS.DifferentFrom`
      - `MS.Functional`
      - `MS.IntroTerm`
      - `MS.InverseFunctional`
      - `MS.Irreflexive`
      - `MS.Is`
      - `MS.Not`
      - `MS.Ontology`
      - `MS.Or`
      - `MS.Reflexive`
      - `MS.RemoveIterNumber`
      - `MS.SameAs`
      - `MS.Self`
      - `MS.Single`
      - `MS.Symmetric`
      - `MS.Transitive`
      - `MS.belongsTo`
      - `MS.equivalentTo`
      - `MS.exactly`
      - `MS.forWhich`
      - `MS.langRange`
      - `MS.length`
      - `MS.max`
      - `MS.maxExclusive`
      - `MS.maxInclusive`
      - `MS.maxLength`
      - `MS.min`
      - `MS.minExclusive`
      - `MS.minInclusive`
      - `MS.minLength`
      - `MS.o`
      - `MS.of`
      - `MS.onClass`
      - `MS.onProperty`
      - `MS.only`
      - `MS.pattern`
      - `MS.some`
      - `MS.subPropertyChain`
      - `MS.that`
      - `MS.value`
  - Module contents

## Submodules

## cemento.axioms.constants module

cemento.axioms.constants.get_ms_turtle_mapping() → dict[URIRef, URIRef]

## cemento.axioms.extract_axioms module

cemento.axioms.extract_axioms.expand_tree(term_graph, restriction_nodes, pivot_nodes) → tuple[DiGraph, dict[str, URIRef]]

cemento.axioms.extract_axioms.extract_axiom_graph(term_graph, term_substitution, restriction_nodes, collection_headers, intro_restriction_triples, faceted_terms) → Graph

cemento.axioms.extract_axioms.infer_number_str_type(number_str: str) → URIRef

cemento.axioms.extract_axioms.parse_chain_tuple(input_tuple, collection_headers, term_substitution, facet_substitution, ms_turtle_mapping)

cemento.axioms.extract_axioms.parse_item(item, collection_headers, term_substitution, facet_substitution, ms_turtle_mapping) → URIRef

cemento.axioms.extract_axioms.retrieve_facet_nodes(facet_graph, term_substitution, faceted_terms) → tuple[Graph, dict[str, BNode]]

## Module contents